VCFRIDER is a collection of Python commands intended to be used for gene casting from genome VCF, from data importing, cleaning-up, annotation by gene list. (from SURPY import soap as sp)

Data importing from CSV file.

Manual will come later.

